@@ -1,79 +1,25 @@
 import logging
 import pathlib
-from typing import Any
-from typing import Dict, Tuple, List
+from typing import Any, Dict, List, Tuple
 
+import numpy as np
 from allennlp.common.file_utils import cached_path
-from allennlp.data import Vocabulary
 from allennlp.data.dataset_readers.dataset_reader import DatasetReader
-from allennlp.data.fields import Field, TextField, SequenceLabelField, MetadataField
+from allennlp.data.fields import ArrayField, Field, MetadataField, SequenceLabelField, TextField
 from allennlp.data.instance import Instance
-from allennlp.data.token_indexers import (
-    TokenIndexer,
-    PretrainedTransformerIndexer,
-)
+from allennlp.data.token_indexers import PretrainedTransformerIndexer, TokenIndexer
 from allennlp.data.tokenizers import Token
 from allennlp_models.common.ontonotes import Ontonotes
 from allennlp_models.structured_prediction import SrlReader
 from conllu import parse_incr
 from overrides import overrides
-from transformers import AutoTokenizer
-
-from transformer_srl.utils import load_label_list
+from transformers import AutoTokenizer, XLMRobertaTokenizer
 
 logger = logging.getLogger(__name__)
 
 FRAME_LIST_PATH = pathlib.Path(__file__).resolve().parent / "resources" / "framelist.txt"
 
 
-"""
-ID: Word index, integer starting at 1 for each new sentence; may be a range for tokens with multiple words.
-FORM: Word form or punctuation symbol.
-LEMMA: Lemma or stem of word form.
-UPOSTAG: Universal part-of-speech tag drawn from our revised version of the Google universal POS tags.
-XPOSTAG: Language-specific part-of-speech tag; underscore if not available.
-FEATS: List of morphological features from the universal feature inventory or from a defined language-specific extension; underscore if not available.
-HEAD: Head of the current token, which is either a value of ID or zero (0).
-DEPREL: Universal Stanford dependency relation to the HEAD (root iff HEAD = 0) or a defined language-specific subtype of one.
-DEPS: List of secondary dependencies (head-deprel pairs).
-MISC: Any other annotation.
-"""
-
-conllu_fields = [
-    "id",
-    "form",
-    "lemma",
-    "upostag",
-    "xpostag",
-    "feats",
-    "head",
-    "deprel",
-    "dunno",
-    "dunno2",
-    "frame",
-    "roles",
-]
-
-
-conll2009_fields = [
-    "id",
-    "form",
-    "lemma",
-    "plemma",
-    "pos",
-    "ppos",
-    "feat",
-    "pfeat",
-    "head",
-    "phead",
-    "deprel",
-    "pdeprel",
-    "fillpred",
-    "frame",
-    "roles",
-]
-
-
 def _convert_verb_indices_to_wordpiece_indices(
     verb_indices: List[int], offsets: List[int], binary: bool = True
 ):
@@ -256,27 +202,22 @@ class SrlTransformersSpanReader(SrlReader):
                 "Filtering to only include file paths containing the %s domain",
                 self._domain_identifier,
             )
-
-        counter = 0
-        try:
-            for sentence in self._ontonotes_subset(
-                ontonotes_reader, file_path, self._domain_identifier
-            ):
-                tokens = [Token(t) for t in sentence.words]
-                if sentence.srl_frames:
-                    for (_, tags) in sentence.srl_frames:
-                        verb_indicator = [1 if label[-2:] == "-V" else 0 for label in tags]
-                        frames = self._get_predicate_labels(sentence, verb_indicator)
-                        lemmas = [
-                            f for f, v in zip(sentence.predicate_lemmas, verb_indicator) if v == 1
-                        ]
-                        if not all(v == 0 for v in verb_indicator):
-                            yield self.text_to_instance(
-                                tokens, verb_indicator, frames, lemmas, tags
-                            )
-                counter += 1
-        except:
-            print("COUNTER", counter)
+        for sentence in self._ontonotes_subset(
+            ontonotes_reader, file_path, self._domain_identifier
+        ):
+            tokens = [Token(t) for t in sentence.words]
+            sentence_id = sentence.sentence_id
+            if sentence.srl_frames:
+                for (_, tags) in sentence.srl_frames:
+                    verb_indicator = [1 if label[-2:] == "-V" else 0 for label in tags]
+                    frames = self._get_predicate_labels(sentence, verb_indicator)
+                    lemmas = [
+                        f for f, v in zip(sentence.predicate_lemmas, verb_indicator) if v == 1
+                    ]
+                    if not all(v == 0 for v in verb_indicator):
+                        yield self.text_to_instance(
+                            tokens, verb_indicator, frames, lemmas, tags, sentence_id
+                        )
 
     def text_to_instance(  # type: ignore
         self,
@@ -285,6 +226,7 @@ class SrlTransformersSpanReader(SrlReader):
         frames: List[str] = None,
         lemmas: List[str] = None,
         tags: List[str] = None,
+        sentence_id=None,
     ) -> Instance:
         """
         We take `pre-tokenized` input here, along with a verb label.  The verb label should be a
@@ -298,7 +240,15 @@ class SrlTransformersSpanReader(SrlReader):
         )
         new_verbs = _convert_verb_indices_to_wordpiece_indices(verb_label, offsets)
         frame_indicator = _convert_frames_indices_to_wordpiece_indices(verb_label, offsets, True)
-        metadata_dict["offsets"] = start_offsets
+
+        # add verb as information to the model
+        # verb_tokens = [token for token, v in zip(wordpieces, new_verbs) if v == 1]
+        # verb_tokens = verb_tokens + [self.tokenizer.sep_token]
+        # if isinstance(self.tokenizer, XLMRobertaTokenizer):
+        #     verb_tokens = [self.tokenizer.sep_token] + verb_tokens
+        # wordpieces += verb_tokens
+        # new_verbs += [0 for _ in range(len(verb_tokens))]
+        # frame_indicator += [0 for _ in range(len(verb_tokens))]
         # In order to override the indexing mechanism, we need to set the `text_id`
         # attribute directly. This causes the indexing to use this id.
         text_field = TextField(
@@ -308,6 +258,9 @@ class SrlTransformersSpanReader(SrlReader):
         verb_indicator = SequenceLabelField(new_verbs, text_field)
         frame_indicator = SequenceLabelField(frame_indicator, text_field)
 
+
+        metadata_dict["offsets"] = start_offsets
+
         fields: Dict[str, Field] = {
             "tokens": text_field,
             "verb_indicator": verb_indicator,
@@ -325,10 +278,16 @@ class SrlTransformersSpanReader(SrlReader):
         metadata_dict["lemmas"] = lemmas
         metadata_dict["verb"] = verb
         metadata_dict["verb_index"] = verb_index
+        metadata_dict["sentence_id"] = sentence_id
 
         if tags:
+            # roles
             new_tags = self._convert_tags_to_wordpiece_tags(tags, offsets)
+            new_tags += ["O" for _ in range(len(wordpieces) - len(new_tags))]
+            # frames
             new_frames = _convert_frames_indices_to_wordpiece_indices(frames, offsets)
+            new_frames += ["O" for _ in range(len(wordpieces) - len(new_frames))]
+            # for model
             fields["tags"] = SequenceLabelField(new_tags, text_field)
             fields["frame_tags"] = SequenceLabelField(
                 new_frames, text_field, label_namespace="frames_labels"
@@ -385,25 +344,67 @@ class SrlTransformersSpanReader(SrlReader):
 
     def _get_predicate_labels(self, sentence, verb_indicator):
         labels = []
-        try:
-            for i, v in enumerate(verb_indicator):
-                if v == 1:
-                    label = (
-                        "{}.{}".format(
-                            sentence.predicate_lemmas[i], sentence.predicate_framenet_ids[i]
-                        )
-                        if sentence.predicate_framenet_ids[i].isdigit()
-                        else sentence.predicate_framenet_ids[i]
-                    )
-                    labels.append(label)
-                else:
-                    labels.append("O")
-        except:
-            print(sentence.words)
-            print(sentence.predicate_framenet_ids)
+        for i, v in enumerate(verb_indicator):
+            if v == 1:
+                label = (
+                    "{}.{}".format(sentence.predicate_lemmas[i], sentence.predicate_framenet_ids[i])
+                    if sentence.predicate_framenet_ids[i].isdigit()
+                    else sentence.predicate_framenet_ids[i]
+                )
+                labels.append(label)
+            else:
+                labels.append("O")
         return labels
 
 
+"""
+ID: Word index, integer starting at 1 for each new sentence; may be a range for tokens with multiple words.
+FORM: Word form or punctuation symbol.
+LEMMA: Lemma or stem of word form.
+UPOSTAG: Universal part-of-speech tag drawn from our revised version of the Google universal POS tags.
+XPOSTAG: Language-specific part-of-speech tag; underscore if not available.
+FEATS: List of morphological features from the universal feature inventory or from a defined language-specific extension; underscore if not available.
+HEAD: Head of the current token, which is either a value of ID or zero (0).
+DEPREL: Universal Stanford dependency relation to the HEAD (root iff HEAD = 0) or a defined language-specific subtype of one.
+DEPS: List of secondary dependencies (head-deprel pairs).
+MISC: Any other annotation.
+"""
+
+conllu_fields = [
+    "id",
+    "form",
+    "lemma",
+    "upostag",
+    "xpostag",
+    "feats",
+    "head",
+    "deprel",
+    "dunno",
+    "dunno2",
+    "frame",
+    "roles",
+]
+
+
+conll2009_fields = [
+    "id",
+    "form",
+    "lemma",
+    "plemma",
+    "pos",
+    "ppos",
+    "feat",
+    "pfeat",
+    "head",
+    "phead",
+    "deprel",
+    "pdeprel",
+    "fillpred",
+    "frame",
+    "roles",
+]
+
+
 @DatasetReader.register("transformer_srl_dependency")
 class SrlUdpDatasetReader(SrlTransformersSpanReader):
     """
